@@ -6,7 +6,10 @@ if PYQT_VERSIONS == "PyQt5":
         QPainter,
         QResizeEvent,
         QMouseEvent,
+        QMoveEvent,
         QPaintEvent,
+        QInputMethodEvent,
+        QKeyEvent,
         QColor,
         QPen,
         QPainterPath,
@@ -28,7 +31,10 @@ if PYQT_VERSIONS == "PyQt6":
         QPainter,
         QResizeEvent,
         QMouseEvent,
+        QMoveEvent,
         QPaintEvent,
+        QInputMethodEvent,
+        QKeyEvent,
         QColor,
         QPen,
         QPainterPath,
@@ -50,7 +56,10 @@ if PYQT_VERSIONS == "PySide2":
         QPainter,
         QResizeEvent,
         QMouseEvent,
+        QMoveEvent,
         QPaintEvent,
+        QInputMethodEvent,
+        QKeyEvent,
         QColor,
         QPen,
         QPainterPath,
@@ -73,7 +82,10 @@ if PYQT_VERSIONS == "PySide6":
         QPainter,
         QResizeEvent,
         QMouseEvent,
+        QMoveEvent,
         QPaintEvent,
+        QInputMethodEvent,
+        QKeyEvent,
         QColor,
         QPen,
         QPainterPath,
